@@ -581,7 +581,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	    g_mkdir_with_parents (mime_dir, 0700) == -1) {
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Unable to create cache path '%s': %s"),
+			_("Unable to create cache path “%s”: %s"),
 			mime_dir, g_strerror (errno));
 		g_free (mime_dir);
 		goto exit;
@@ -673,7 +673,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	if (g_mkdir_with_parents (dir, 0700) == -1) {
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
-			_("Unable to create cache path '%s': %s"),
+			_("Unable to create cache path “%s”: %s"),
 			dir, g_strerror (errno));
 		g_free (dir);
 		g_free (cache_file);
@@ -687,7 +687,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 			/* Translators: The first %s consists of the source file name,
 			   the second %s of the destination file name and
 			   the third %s of the error message. */
-			_("Failed to move message cache file from '%s' to '%s': %s"),
+			_("Failed to move message cache file from “%s” to “%s”: %s"),
 			mime_content, cache_file, g_strerror (errno));
 		g_free (cache_file);
 		goto exit;
@@ -1879,7 +1879,7 @@ ews_refresh_info_sync (CamelFolder *folder,
 	id = camel_ews_store_summary_get_folder_id_from_name (
 		ews_store->summary, full_name);
 
-	camel_operation_push_message (cancellable, _("Refreshing folder '%s'"), camel_folder_get_display_name (folder));
+	camel_operation_push_message (cancellable, _("Refreshing folder “%s”"), camel_folder_get_display_name (folder));
 
 	/* Sync folder items does not return the fields ToRecipients,
 	 * CCRecipients. With the item_type unknown, its not possible
